@@ -1,14 +1,15 @@
-use tracing::{debug, error};
-
-use crate::paths;
 use std::{
-    fmt,
+    env, fmt,
     fs::{create_dir_all, File},
     io::Read,
     ops::Deref,
     path::Path,
 };
 
+use tracing::{debug, error};
+
+use crate::paths;
+
 #[must_use]
 pub struct TestOutput<R> {
     /// Errors produced by `swc_common::error::Handler`.
@@ -90,7 +91,7 @@ impl NormalizedOutput {
         debug!("Comparing output to {}", path.display());
         create_dir_all(path.parent().unwrap()).expect("failed to run `mkdir -p`");
 
-        if std::env::var("UPDATE").unwrap_or(String::from("0")) == "1" {
+        if std::env::var("UPDATE").unwrap_or_default() == "1" {
             crate::write_to_file(&path, &self.0);
 
             error!(
@@ -108,7 +109,11 @@ impl NormalizedOutput {
             actual: self,
         };
 
-        pretty_assertions::assert_eq!(diff.expected, diff.actual, "Actual:\n{}", diff.actual);
+        if env::var("DIFF").unwrap_or_default() == "0" {
+            assert_eq!(diff.expected, diff.actual, "Actual:\n{}", diff.actual);
+        } else {
+            pretty_assertions::assert_eq!(diff.expected, diff.actual, "Actual:\n{}", diff.actual);
+        }
 
         // Actually unreachable.
         Err(diff)
@@ -124,10 +129,10 @@ impl From<String> for NormalizedOutput {
         let manifest_dirs = vec![
             adjust_canonicalization(paths::manifest_dir()),
             paths::manifest_dir().to_string_lossy().to_string(),
-            adjust_canonicalization(paths::manifest_dir()).replace("\\", "\\\\"),
+            adjust_canonicalization(paths::manifest_dir()).replace('\\', "\\\\"),
             paths::manifest_dir()
                 .to_string_lossy()
-                .replace("\\", "\\\\"),
+                .replace('\\', "\\\\"),
         ];
 
         let s = s.replace("\r\n", "\n");
@@ -140,7 +145,7 @@ impl From<String> for NormalizedOutput {
                 for dir in &manifest_dirs {
                     s = s.replace(&**dir, "$DIR");
                 }
-                s = s.replace("\\\\", "\\").replace("\\", "/");
+                s = s.replace("\\\\", "\\").replace('\\', "/");
                 let s = if cfg!(target_os = "windows") {
                     s.replace("//?/$DIR", "$DIR").replace("/?/$DIR", "$DIR")
                 } else {
@@ -148,7 +153,7 @@ impl From<String> for NormalizedOutput {
                 };
                 buf.push_str(&s)
             } else {
-                buf.push_str(&line);
+                buf.push_str(line);
             }
             buf.push('\n')
         }
@@ -159,6 +164,7 @@ impl From<String> for NormalizedOutput {
 
 impl Deref for NormalizedOutput {
     type Target = str;
+
     fn deref(&self) -> &str {
         &self.0
     }
@@ -182,8 +188,8 @@ fn adjust_canonicalization<P: AsRef<Path>>(p: P) -> String {
 fn adjust_canonicalization<P: AsRef<Path>>(p: P) -> String {
     const VERBATIM_PREFIX: &str = r#"\\?\"#;
     let p = p.as_ref().display().to_string();
-    if p.starts_with(VERBATIM_PREFIX) {
-        p[VERBATIM_PREFIX.len()..].to_string()
+    if let Some(stripped) = p.strip_prefix(VERBATIM_PREFIX) {
+        stripped.to_string()
     } else {
         p
     }
